package cn.hnthyy.thmz.service.impl.thmz;

import cn.hnthyy.thmz.entity.thmz.Mzmxsr;
import cn.hnthyy.thmz.mapper.thmz.MzmxsrMapper;
import cn.hnthyy.thmz.service.thmz.MzmxsrService;
import cn.hnthyy.thmz.vo.ThmzmxsrParamsVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.List;
@Service
public class MzmxsrServiceImpl implements MzmxsrService {
    @SuppressWarnings("all")
    @Autowired
    private MzmxsrMapper mzmxsrMapper;
    @Override
    public int saveMzmxsr(Mzmxsr mzmxsr) {
        return mzmxsrMapper.insertMzmxsr(mzmxsr);
    }

    @Override
    public int batchSaveMzmxsr(List<Mzmxsr> mzmxsrList) {
        return mzmxsrMapper.batchInsertMzmxsr(mzmxsrList);
    }

    @Override
    public List<Mzmxsr> queryMzmxsrWithPage(ThmzmxsrParamsVo thmzmxsrParamsVo) {
        return mzmxsrMapper.selectMzmxsrWithPage(thmzmxsrParamsVo);
    }

    @Override
    public Integer queryCountMzmxsr(ThmzmxsrParamsVo thmzmxsrParamsVo) {
        return mzmxsrMapper.selectCountMzmxsr(thmzmxsrParamsVo);
    }

    @Override
    public BigDecimal querySumAmount(ThmzmxsrParamsVo thmzmxsrParamsVo) {
        return mzmxsrMapper.selectSumAmount(thmzmxsrParamsVo);
    }

    @Override
    public List<String> queryAllPatientId(String beginDate, String endDate) {
        return mzmxsrMapper.selectAllPatientId(beginDate,endDate);
    }
}
